@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::RJBS;
 # ABSTRACT: BeLike::RJBS when you build your dists
-$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.006';
+$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.007';
 use Moose;
 use Dist::Zilla 2.100922; # TestRelease
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -39,6 +39,8 @@ with 'Dist::Zilla::Role::PluginBundle::Easy';
 #pod   [@Git]
 #pod   tag_format = %v
 #pod
+#pod   [Git::Contributors]
+#pod
 #pod If the C<task> argument is given to the bundle, PodWeaver is replaced with
 #pod TaskWeaver and Git::NextVersion is replaced with AutoVersion.  If the
 #pod C<manual_version> argument is given, AutoVersion is omitted.
@@ -204,6 +206,8 @@ sub configure {
       'github :',
     ],
   });
+
+  $self->add_plugins('Git::Contributors');
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -222,7 +226,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.006
+version 5.007
 
 =head1 DESCRIPTION
 
@@ -258,6 +262,8 @@ This is the plugin bundle that RJBS uses.  It is more or less equivalent to:
   [@Git]
   tag_format = %v
 
+  [Git::Contributors]
+
 If the C<task> argument is given to the bundle, PodWeaver is replaced with
 TaskWeaver and Git::NextVersion is replaced with AutoVersion.  If the
 C<manual_version> argument is given, AutoVersion is omitted.
@@ -269,6 +275,12 @@ point to GitHub issues for the dist's bugtracker.
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Ricardo Signes.
